@@ -1,7 +1,14 @@
-from .serialize import dask_serialize, dask_deserialize, serialize, deserialize
+from __future__ import annotations
 
 import netCDF4
 
+from distributed.protocol.serialize import (
+    dask_deserialize,
+    dask_serialize,
+    deserialize,
+    serialize,
+)
+
 
 @dask_serialize.register(netCDF4.Dataset)
 def serialize_netcdf4_dataset(ds):
